@@ -15,35 +15,29 @@ new-release - the Business::Shipping release script.
  # 
  # Manual: Update the CHANGELOG
  #
- 
- #
- # Make sure all the files (documentation, etc.) are up to date.
- #
  # Make sure that the manifest didn't get any extra stuff:
  # rm MANIFEST; make manifest; svn diff MANIFEST | more
  #
  # UPDATE META.yml
  #
- # Then commit to CVS
- #
  perl Makefile.PL
  make docs && make && make test
  svn commit
  
- #
  # Delete old file, make new file, and upload to server.
  # Upload the new version to CPAN, for PAUSE
  # Update to the next verision in Makefile.PL (if you haven't already)
+ # Note that cpan-upload requires AppConfig AppConfig::Std
  #
- export VERSION_AFTER_THIS_UPLOAD=1.52
+ # export VERSION_AFTER_THIS_UPLOAD=1.52
+ 
  rm Business-Shipping-*.tar.gz
  make tardist
  bin/new-release.pl Business-Shipping-*.tar.gz
  cpan-upload -user `cat ~/.apps/.PAUSE-user` -password `cat ~/.apps/.PAUSE-password` -mailto 'db@kavod.com' -non_interactive Business-Shipping-*.tar.gz
- #
+ 
  # This version updater doesn't work now that I've changed the Makefile.PL.
  # perl -pi -e "s/\$VERSION = \'.\...\'/\$VERSION = \'${VERSION_AFTER_THIS_UPLOAD}\'/g" Makefile.PL
- #
  
 =cut 
 
@@ -78,9 +72,9 @@ tar zxf $file
 ln -s $file Business-Shipping-latest.tar.gz
 ln -s $version Business-Shipping-latest
 
-# Update CVS
-cd CVS-Business-Shipping
-cvs up
+# TODO: Auto update subversion
+# cd SVN-Business-Shipping
+# cvs up
 
 # Update version number
 cd ..
