@@ -6,14 +6,13 @@ use warnings;
 use Business::Shipping;
 use Business::Shipping::Shipment;
 use Business::Shipping::Shipment::UPS;
-use Business::Shipping::Shipment::USPS;
 use Business::Shipping::Package;
 use Business::Shipping::Package::UPS;
-use Business::Shipping::Package::USPS;
 use Business::Shipping::RateRequest;
 use Business::Shipping::RateRequest::Online;
 use Business::Shipping::UPS_Online::RateRequest;
 use Business::Shipping::USPS_Online::RateRequest;
+
 my $rate_request;
 
 
